@@ -69,6 +69,7 @@ KNutClient::KNutClient(bool noDock, QObject* parent, const char *name) : QObject
     connect(myDock, SIGNAL(printUPSVars()),this, SLOT(slotPrintUPSVars()));
     connect(myDock, SIGNAL(instComms()),this, SLOT(slotInstComms()));
     connect(myDock, SIGNAL(RWVars()),this, SLOT(slotRWVars()));
+    connect(myDock, SIGNAL(makeRefreshConnection()),this, SLOT(slotRefreshConnection()));
     }
   
   addEventString(i18n("Ready."));
@@ -95,7 +96,7 @@ KNutClient::KNutClient(bool noDock, QObject* parent, const char *name) : QObject
   }
 
   
-KNutClient::~KNutClient() {
+KNutClient::~KNutClient(void) {
 
   if (myMessMan) delete myMessMan;
 
@@ -228,7 +229,7 @@ void KNutClient::initVars (void) {
 void KNutClient::saveConfiguration ( bool all ) {
   QString groupName;
   QString codeName;
-  upsRecord upsData; // struktura obsahuje udaje o UPS
+  upsRecord upsData; // struktura obsahuje udaje o UPS structure includes information about UPS
   int upsCount = upsRecords->getCount();
 
   kapp->config()->setGroup ("");
@@ -607,6 +608,7 @@ void KNutClient::setNewUPS (QString name) {
 
   if (name  != mainUpsInfo.record.name) {
     // nastavime na docku iconu
+    // sets icon for dock
     if (myDock) {
       myDock->initImage();
       myDock->repaint();
@@ -724,7 +726,7 @@ void KNutClient::slotSetConfig (unsigned int changeSetting) {
   }
 
 
-void KNutClient::slotPrintUPSVars() {
+void KNutClient::slotPrintUPSVars(void) {
 
   if (!mainUpsInfo.errorUpsData) {
     if ((mainUpsInfo.upsNet->readNumberVars (KNutNet::AllVars)) || (mainUpsInfo.upsNet->readNumberComms ())) {
@@ -736,7 +738,7 @@ void KNutClient::slotPrintUPSVars() {
   }
 
 
-void KNutClient::slotInstComms() {
+void KNutClient::slotInstComms(void) {
 
   if (!mainUpsInfo.errorUpsData) {
     if (mainUpsInfo.upsNet->readNumberComms ()) {
@@ -747,7 +749,7 @@ void KNutClient::slotInstComms() {
     }
   }
 
-void KNutClient::slotRWVars() {
+void KNutClient::slotRWVars(void) {
 
   if (!mainUpsInfo.errorUpsData) {
     if (mainUpsInfo.upsNet->readNumberVars (KNutNet::RWVars)) {
@@ -758,7 +760,54 @@ void KNutClient::slotRWVars() {
       }
     }
   }
-    
+
+
+void KNutClient::slotRefreshConnection(void) {
+
+
+
+
+
+
+
+
+    // nastavime na docku iconu
+    // sets icon for dock
+    if (myDock) {
+      myDock->initImage();
+      myDock->repaint();
+      }
+    upsDeactivate();
+    // procedure upsDeactivate includes command upsTimer->stop
+    addEventString(i18n("Reconnect"),mainUpsInfo.record.name);
+    if (myMessMan) myMessMan->deleteMessage();
+
+//    mainUpsInfo.record.name=name;
+    mainUpsInfo.errorUpsData=false;
+    setActiveUpsInfo(mainUpsInfo.record.name);
+    upsActivate();
+
+    // zde je nutno hned provest prekresleni
+    //we need to repaint here instantly
+    if (mainWindow) {
+      mainWindow->setCombo(mainUpsInfo.record.name);
+      mainWindow->showUpsData();
+      }
+    if (myDock) {
+      myDock->repaintDock(true);
+      myDock->setNewUPS();
+      }
+
+    panelsAreZeroing=false;
+    lastError=0; // zadna chyba
+    mainUpsInfo.oldStatus=KNutNet::initStatus;
+
+    if ((mainUpsInfo.upsNet->getState() == KNutNet::Connected) && (!mainUpsInfo.errorUpsData)) {
+      showStatusEvent();
+      upsTimer->start( mainUpsInfo.record.delay, TRUE ); // nastartujeme casovac
+      }
+  }
+                
 
 void KNutClient::slotChangeRWVars( QString varName) {
   // informace ze doslo k uspesne zmene promene
@@ -792,7 +841,10 @@ void KNutClient::makeMainWindow (void) {
   connect(mainWindow, SIGNAL(showUPSVars()),this, SLOT(slotPrintUPSVars()));
   connect(mainWindow, SIGNAL(makeInstComms()),this, SLOT(slotInstComms()));
   connect(mainWindow, SIGNAL(makeRWVars()),this, SLOT(slotRWVars()));
+  connect(mainWindow, SIGNAL(makeRefreshConnection()),this, SLOT(slotRefreshConnection()));
 
+
+  
   connect(mainWindow, SIGNAL(endApplication()), this, SLOT(slotExitApplication()));
   connect(mainWindow, SIGNAL(destroyed()), this, SLOT(exitMainWindow()));
   }
