@@ -81,26 +81,10 @@ KNutPrintUpsVar::KNutPrintUpsVar(KNutNet* const upsNet, const bool useDescriptio
     upsVarsMainLayout->addWidget(table);
 
 
-    #if defined  (KDE_VERSION_MAJOR)
-      #if KDE_VERSION_MAJOR >= 3
-        KListViewItem* myListItem;
-      #else
-        QListViewItem* myListItem;
-      #endif
-    #else
-      QListViewItem* myListItem;
-    #endif
-      
+    KListViewItem* myListItem;
     if (countIComms) {
-      #if defined  (KDE_VERSION_MAJOR)
-        #if KDE_VERSION_MAJOR >= 3
-         ICommList = new KListViewItem( table, i18n("Instant Commands"));
-        #else
-          ICommList = new QListViewItem( table, i18n("Instant Commands"));
-        #endif
-      #else
-        ICommList = new QListViewItem( table, i18n("Instant Commands"));
-      #endif
+      
+      ICommList = new KListViewItem( table, i18n("Instant Commands"));
       ICommList->setOpen(true);
 
       for (int i=0; i<countIComms; i++) {
@@ -113,15 +97,7 @@ KNutPrintUpsVar::KNutPrintUpsVar(KNutNet* const upsNet, const bool useDescriptio
      }
     
     if (countRWVars) {
-    #if defined  (KDE_VERSION_MAJOR)
-      #if KDE_VERSION_MAJOR >= 3
-        RWVarsList = new KListViewItem( table, i18n("Read/Write Variables"));
-      #else
-        RWVarsList = new QListViewItem( table, i18n("Read/Write Variables"));
-      #endif
-    #else
-      RWVarsList = new QListViewItem( table, i18n("Read/Write Variables"));
-    #endif
+      RWVarsList = new KListViewItem( table, i18n("Read/Write Variables"));
       RWVarsList->setOpen(true);
       for (int i=0; i<countVars; i++) {
         myUpsNet->readVars(i+1,myStructVar);
@@ -133,29 +109,13 @@ KNutPrintUpsVar::KNutPrintUpsVar(KNutNet* const upsNet, const bool useDescriptio
        if ((!myStructVar.upsDescription.isEmpty()) && useDescription)
           pointerVar.myValue->setText(2,myStructVar.upsDescription);
 
-         #if defined  (KDE_VERSION_MAJOR)
-           #if KDE_VERSION_MAJOR >= 3
-             dataList.push_back(pointerVar);
-           #else
-             dataList.append(pointerVar);
-           #endif
-         #else
-           dataList.append(pointerVar);
-         #endif
+          dataList.push_back(pointerVar);
          }
        }
      }
 
 
-    #if defined  (KDE_VERSION_MAJOR)
-      #if KDE_VERSION_MAJOR >= 3
-        ROVarsList = new KListViewItem( table, i18n("Read Only Variables"));
-      #else
-        ROVarsList = new QListViewItem( table, i18n("Read Only Variables"));
-      #endif
-    #else
-      ROVarsList = new QListViewItem( table, i18n("Read Only Variables"));
-    #endif
+    ROVarsList = new KListViewItem( table, i18n("Read Only Variables"));
     ROVarsList->setOpen(true);
 
     for (int i=0; i<countVars; i++) {
@@ -168,15 +128,7 @@ KNutPrintUpsVar::KNutPrintUpsVar(KNutNet* const upsNet, const bool useDescriptio
        if ((!myStructVar.upsDescription.isEmpty()) && useDescription)
           pointerVar.myValue->setText(2,myStructVar.upsDescription);
 
-       #if defined  (KDE_VERSION_MAJOR)
-         #if KDE_VERSION_MAJOR >= 3
-           dataList.push_back(pointerVar);
-         #else
-           dataList.append(pointerVar);
-         #endif
-       #else
-         dataList.append(pointerVar);
-       #endif
+       dataList.push_back(pointerVar);
        }
      }  
 
@@ -199,15 +151,7 @@ void KNutPrintUpsVar::slotReloadVars (void) {
     KNutVarData::showError (myUpsNet->getError());
   else {
 
-  #if defined  (KDE_VERSION_MAJOR)
-    #if KDE_VERSION_MAJOR >= 3
-      QValueVector<dataVar>::const_iterator it;
-    #else
-      QValueList<dataVar>::ConstIterator it;
-    #endif
-  #else
-    QValueList<dataVar>::ConstIterator it;
-  #endif
+    QValueVector<dataVar>::const_iterator it;
     for (it = dataList.begin(); it != dataList.end(); it++) {
       myUpsNet->readVars((*it).myName,myStructVar);
       (*it).myValue->setText (1,myStructVar.upsValue);
@@ -215,21 +159,9 @@ void KNutPrintUpsVar::slotReloadVars (void) {
     }
   }
 
-#if defined  (KDE_VERSION_MAJOR)
-  #if KDE_VERSION_MAJOR >= 3
-    KListViewItem* KNutPrintUpsVar::addListItem (KListViewItem* table, QString varName, QString value) {
-    KListViewItem* myListItem;
-    KListViewItem* helpListItem;
-  #else
-    QListViewItem* KNutPrintUpsVar::addListItem (QListViewItem* table, QString varName, QString value) {
-    QListViewItem* myListItem;
-    QListViewItem* helpListItem;
-  #endif
-#else
-  QListViewItem* KNutPrintUpsVar::addListItem (QListViewItem* table, QString varName, QString value) {
-  QListViewItem* myListItem;
-  QListViewItem* helpListItem;
-#endif
+  KListViewItem* KNutPrintUpsVar::addListItem (KListViewItem* table, QString varName, QString value) {
+  KListViewItem* myListItem;
+  KListViewItem* helpListItem;
   QString left;
   int n;
 
@@ -240,30 +172,14 @@ void KNutPrintUpsVar::slotReloadVars (void) {
       left = varName.left(n);
       varName = varName.mid(n+1);
       if (!(helpListItem = existListItem( myListItem,left))) {
-        #if defined  (KDE_VERSION_MAJOR)
-          #if KDE_VERSION_MAJOR >= 3
-            myListItem = new KListViewItem( myListItem, left);
-          #else
-            myListItem = new QListViewItem( myListItem, left);
-          #endif
-        #else
-          myListItem = new QListViewItem( myListItem, left);
-        #endif
+        myListItem = new KListViewItem( myListItem, left);
         myListItem->setOpen(true);
         }
       else myListItem = helpListItem;
       if (!myListItem->pixmap(0)) myListItem->setPixmap(0,dirPixmap);
       }
     else { // end part
-      #if defined  (KDE_VERSION_MAJOR)
-        #if KDE_VERSION_MAJOR >= 3
-          helpListItem = new KListViewItem( myListItem, varName, value);
-        #else
-          helpListItem = new QListViewItem( myListItem, varName, value);
-        #endif
-      #else
-        helpListItem = new QListViewItem( myListItem, varName, value);
-      #endif
+      helpListItem = new KListViewItem( myListItem, varName, value);
       helpListItem->setOpen(true);
       return helpListItem;
       }
@@ -272,44 +188,18 @@ void KNutPrintUpsVar::slotReloadVars (void) {
   }
 
 
-    #if defined  (KDE_VERSION_MAJOR)
-      #if KDE_VERSION_MAJOR >= 3
-        KListViewItem* KNutPrintUpsVar::existListItem (KListViewItem* listItem, QString name) {
-        KListViewItem*  myItem;
+    KListViewItem* KNutPrintUpsVar::existListItem (KListViewItem* listItem, QString name) {
+    KListViewItem*  myItem;
   
-        if (!(myItem = (KListViewItem *)listItem->firstChild())) return 0l;
-        while (myItem) {
-          if (myItem->text(0) == name) return myItem;
-          myItem = (KListViewItem *)myItem->nextSibling(); 
-          }
-        return 0l;
-        }
-      #else
-        QListViewItem* KNutPrintUpsVar::existListItem (QListViewItem* listItem, QString name) {
-        QListViewItem*  myItem;
- 
-        if (!(myItem = listItem->firstChild())) return 0l;
-        while (myItem) {
-          if (myItem->text(0) == name) return myItem;
-          myItem = myItem->nextSibling(); 
-          }
-       return 0l;
-       }
-      #endif
-    #else
-       QListViewItem* KNutPrintUpsVar::existListItem (QListViewItem* listItem, QString name) {
-       QListViewItem*  myItem;
-  
-       if (!(myItem = listItem->firstChild())) return 0l;
-       while (myItem) {
-        if (myItem->text(0) == name) return myItem;
-        myItem = myItem->nextSibling(); 
-        }
-      return 0l;
+    if (!(myItem = (KListViewItem *)listItem->firstChild())) return 0l;
+    while (myItem) {
+      if (myItem->text(0) == name) return myItem;
+      myItem = (KListViewItem *)myItem->nextSibling(); 
       }
-    #endif
+    return 0l;
+    }
 
-bool KNutPrintUpsVar::upsOk (void) { return upsConnectOk; };
+bool KNutPrintUpsVar::upsOk (void) { return upsConnectOk; }
 
 
 #include "knutprintupsvar.moc"
